<img src="projecc/logo/black-transp.png" alt="logo" width="200"/>

# projecc
A small simple package for projecting orbital elements onto sky plane and vice versa.

## Installation

Install via pip:
<code>pip install projecc</code>

On the package index: <a href="https://pypi.org/project/projecc/">projecc</a>


## Tutorials

See the <a href="https://github.com/logan-pearce/projecc/blob/main/projecc/UsingProjecc.ipynb">Using Projecc notebook</a> for descriptions, definitions, and examples.

## Change log

#### Feb 27, 2025:
1.1.2 Added date functionality and accomodation for system decl

#### Feb 27, 2025:
1.1.1 Minor bug fixes

#### Jan 27, 2025:
1.1.0 Added classes and funtions for predicting the position of a planet in the sky plane at a given time

#### Oct 14, 2024:
1.0.1 Fixed coordinate system in sep/pa functions

#### Oct 11, 2024:
1.0.1 Fixed coordinate system in KeplerianToCartesian and added Sirius example to notebook

#### Oct 30, 2023:
1.0.0 Initial release
